## Typing stubs for six

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`six`](https://github.com/benjaminp/six) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `six`. This version of
`types-six` aims to provide accurate annotations for
`six==1.17.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/six`](https://github.com/python/typeshed/tree/main/stubs/six)
directory.

This package was tested with
mypy 1.15.0,
pyright 1.1.395,
and pytype 2024.10.11.
It was generated from typeshed commit
[`a3a17b0f0e347b1ae769191a46e2e22168397b05`](https://github.com/python/typeshed/commit/a3a17b0f0e347b1ae769191a46e2e22168397b05).